Documentation
¶
Index ¶
- type AnalyzeNvcRequest
- type AnalyzeNvcResponse
- type AuthenticateSigRequest
- type AuthenticateSigResponse
- type CaptchaCitie
- type CaptchaCities
- type CaptchaDay
- type CaptchaIp
- type CaptchaIps
- type CaptchaMin
- type CaptchaMins
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) AnalyzeNvc(request *AnalyzeNvcRequest) (response *AnalyzeNvcResponse, err error)
- func (client *Client) AnalyzeNvcWithCallback(request *AnalyzeNvcRequest, ...) <-chan int
- func (client *Client) AnalyzeNvcWithChan(request *AnalyzeNvcRequest) (<-chan *AnalyzeNvcResponse, <-chan error)
- func (client *Client) AuthenticateSig(request *AuthenticateSigRequest) (response *AuthenticateSigResponse, err error)
- func (client *Client) AuthenticateSigWithCallback(request *AuthenticateSigRequest, ...) <-chan int
- func (client *Client) AuthenticateSigWithChan(request *AuthenticateSigRequest) (<-chan *AuthenticateSigResponse, <-chan error)
- func (client *Client) ConfigurationStyle(request *ConfigurationStyleRequest) (response *ConfigurationStyleResponse, err error)
- func (client *Client) ConfigurationStyleWithCallback(request *ConfigurationStyleRequest, ...) <-chan int
- func (client *Client) ConfigurationStyleWithChan(request *ConfigurationStyleRequest) (<-chan *ConfigurationStyleResponse, <-chan error)
- func (client *Client) CreateConfiguration(request *CreateConfigurationRequest) (response *CreateConfigurationResponse, err error)
- func (client *Client) CreateConfigurationWithCallback(request *CreateConfigurationRequest, ...) <-chan int
- func (client *Client) CreateConfigurationWithChan(request *CreateConfigurationRequest) (<-chan *CreateConfigurationResponse, <-chan error)
- func (client *Client) DescribeCaptchaDay(request *DescribeCaptchaDayRequest) (response *DescribeCaptchaDayResponse, err error)
- func (client *Client) DescribeCaptchaDayWithCallback(request *DescribeCaptchaDayRequest, ...) <-chan int
- func (client *Client) DescribeCaptchaDayWithChan(request *DescribeCaptchaDayRequest) (<-chan *DescribeCaptchaDayResponse, <-chan error)
- func (client *Client) DescribeCaptchaIpCity(request *DescribeCaptchaIpCityRequest) (response *DescribeCaptchaIpCityResponse, err error)
- func (client *Client) DescribeCaptchaIpCityWithCallback(request *DescribeCaptchaIpCityRequest, ...) <-chan int
- func (client *Client) DescribeCaptchaIpCityWithChan(request *DescribeCaptchaIpCityRequest) (<-chan *DescribeCaptchaIpCityResponse, <-chan error)
- func (client *Client) DescribeCaptchaMin(request *DescribeCaptchaMinRequest) (response *DescribeCaptchaMinResponse, err error)
- func (client *Client) DescribeCaptchaMinWithCallback(request *DescribeCaptchaMinRequest, ...) <-chan int
- func (client *Client) DescribeCaptchaMinWithChan(request *DescribeCaptchaMinRequest) (<-chan *DescribeCaptchaMinResponse, <-chan error)
- func (client *Client) DescribeCaptchaOrder(request *DescribeCaptchaOrderRequest) (response *DescribeCaptchaOrderResponse, err error)
- func (client *Client) DescribeCaptchaOrderWithCallback(request *DescribeCaptchaOrderRequest, ...) <-chan int
- func (client *Client) DescribeCaptchaOrderWithChan(request *DescribeCaptchaOrderRequest) (<-chan *DescribeCaptchaOrderResponse, <-chan error)
- func (client *Client) DescribeCaptchaRisk(request *DescribeCaptchaRiskRequest) (response *DescribeCaptchaRiskResponse, err error)
- func (client *Client) DescribeCaptchaRiskWithCallback(request *DescribeCaptchaRiskRequest, ...) <-chan int
- func (client *Client) DescribeCaptchaRiskWithChan(request *DescribeCaptchaRiskRequest) (<-chan *DescribeCaptchaRiskResponse, <-chan error)
- func (client *Client) DescribeConfigName(request *DescribeConfigNameRequest) (response *DescribeConfigNameResponse, err error)
- func (client *Client) DescribeConfigNameWithCallback(request *DescribeConfigNameRequest, ...) <-chan int
- func (client *Client) DescribeConfigNameWithChan(request *DescribeConfigNameRequest) (<-chan *DescribeConfigNameResponse, <-chan error)
- func (client *Client) DescribeEarlyWarning(request *DescribeEarlyWarningRequest) (response *DescribeEarlyWarningResponse, err error)
- func (client *Client) DescribeEarlyWarningWithCallback(request *DescribeEarlyWarningRequest, ...) <-chan int
- func (client *Client) DescribeEarlyWarningWithChan(request *DescribeEarlyWarningRequest) (<-chan *DescribeEarlyWarningResponse, <-chan error)
- func (client *Client) DescribeOrderInfo(request *DescribeOrderInfoRequest) (response *DescribeOrderInfoResponse, err error)
- func (client *Client) DescribeOrderInfoWithCallback(request *DescribeOrderInfoRequest, ...) <-chan int
- func (client *Client) DescribeOrderInfoWithChan(request *DescribeOrderInfoRequest) (<-chan *DescribeOrderInfoResponse, <-chan error)
- func (client *Client) DescribePersonMachineList(request *DescribePersonMachineListRequest) (response *DescribePersonMachineListResponse, err error)
- func (client *Client) DescribePersonMachineListWithCallback(request *DescribePersonMachineListRequest, ...) <-chan int
- func (client *Client) DescribePersonMachineListWithChan(request *DescribePersonMachineListRequest) (<-chan *DescribePersonMachineListResponse, <-chan error)
- func (client *Client) SetEarlyWarning(request *SetEarlyWarningRequest) (response *SetEarlyWarningResponse, err error)
- func (client *Client) SetEarlyWarningWithCallback(request *SetEarlyWarningRequest, ...) <-chan int
- func (client *Client) SetEarlyWarningWithChan(request *SetEarlyWarningRequest) (<-chan *SetEarlyWarningResponse, <-chan error)
- func (client *Client) UpdateConfigName(request *UpdateConfigNameRequest) (response *UpdateConfigNameResponse, err error)
- func (client *Client) UpdateConfigNameWithCallback(request *UpdateConfigNameRequest, ...) <-chan int
- func (client *Client) UpdateConfigNameWithChan(request *UpdateConfigNameRequest) (<-chan *UpdateConfigNameResponse, <-chan error)
- type CodeData
- type ConfigName
- type ConfigNames
- type ConfigurationStyleRequest
- type ConfigurationStyleResponse
- type CreateConfigurationRequest
- type CreateConfigurationResponse
- type DescribeCaptchaDayRequest
- type DescribeCaptchaDayResponse
- type DescribeCaptchaIpCityRequest
- type DescribeCaptchaIpCityResponse
- type DescribeCaptchaMinRequest
- type DescribeCaptchaMinResponse
- type DescribeCaptchaOrderRequest
- type DescribeCaptchaOrderResponse
- type DescribeCaptchaRiskRequest
- type DescribeCaptchaRiskResponse
- type DescribeConfigNameRequest
- type DescribeConfigNameResponse
- type DescribeEarlyWarningRequest
- type DescribeEarlyWarningResponse
- type DescribeOrderInfoRequest
- type DescribeOrderInfoResponse
- type DescribePersonMachineListRequest
- type DescribePersonMachineListResponse
- type EarlyWarning
- type EarlyWarnings
- type PersonMachine
- type PersonMachineRes
- type PersonMachines
- type SetEarlyWarningRequest
- type SetEarlyWarningResponse
- type UpdateConfigNameRequest
- type UpdateConfigNameResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AnalyzeNvcRequest ¶
type AnalyzeNvcRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
Data string `position:"Query" name:"Data"`
ScoreJsonStr string `position:"Query" name:"ScoreJsonStr"`
}
AnalyzeNvcRequest is the request struct for api AnalyzeNvc
func CreateAnalyzeNvcRequest ¶
func CreateAnalyzeNvcRequest() (request *AnalyzeNvcRequest)
CreateAnalyzeNvcRequest creates a request to invoke AnalyzeNvc API
type AnalyzeNvcResponse ¶
type AnalyzeNvcResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
}
AnalyzeNvcResponse is the response struct for api AnalyzeNvc
func CreateAnalyzeNvcResponse ¶
func CreateAnalyzeNvcResponse() (response *AnalyzeNvcResponse)
CreateAnalyzeNvcResponse creates a response to parse from AnalyzeNvc response
type AuthenticateSigRequest ¶
type AuthenticateSigRequest struct {
*requests.RpcRequest
Sig string `position:"Query" name:"Sig"`
RemoteIp string `position:"Query" name:"RemoteIp"`
SourceIp string `position:"Query" name:"SourceIp"`
AppKey string `position:"Query" name:"AppKey"`
SessionId string `position:"Query" name:"SessionId"`
Token string `position:"Query" name:"Token"`
Scene string `position:"Query" name:"Scene"`
}
AuthenticateSigRequest is the request struct for api AuthenticateSig
func CreateAuthenticateSigRequest ¶
func CreateAuthenticateSigRequest() (request *AuthenticateSigRequest)
CreateAuthenticateSigRequest creates a request to invoke AuthenticateSig API
type AuthenticateSigResponse ¶
type AuthenticateSigResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code int `json:"Code" xml:"Code"`
Msg string `json:"Msg" xml:"Msg"`
RiskLevel string `json:"RiskLevel" xml:"RiskLevel"`
Detail string `json:"Detail" xml:"Detail"`
}
AuthenticateSigResponse is the response struct for api AuthenticateSig
func CreateAuthenticateSigResponse ¶
func CreateAuthenticateSigResponse() (response *AuthenticateSigResponse)
CreateAuthenticateSigResponse creates a response to parse from AuthenticateSig response
type CaptchaCitie ¶
type CaptchaCitie struct {
Location string `json:"Location" xml:"Location"`
Lat string `json:"Lat" xml:"Lat"`
Lng string `json:"Lng" xml:"Lng"`
Pv int `json:"Pv" xml:"Pv"`
}
CaptchaCitie is a nested struct in afs response
type CaptchaCities ¶
type CaptchaCities struct {
CaptchaCitie []CaptchaCitie `json:"CaptchaCitie" xml:"CaptchaCitie"`
}
CaptchaCities is a nested struct in afs response
type CaptchaDay ¶
type CaptchaDay struct {
Init int `json:"Init" xml:"Init"`
AskForVerify int `json:"AskForVerify" xml:"AskForVerify"`
DirecetStrategyInterception int `json:"DirecetStrategyInterception" xml:"DirecetStrategyInterception"`
TwiceVerify int `json:"TwiceVerify" xml:"TwiceVerify"`
Pass int `json:"Pass" xml:"Pass"`
CheckTested int `json:"CheckTested" xml:"CheckTested"`
UncheckTested int `json:"UncheckTested" xml:"UncheckTested"`
LegalSign int `json:"LegalSign" xml:"LegalSign"`
MaliciousFlow int `json:"MaliciousFlow" xml:"MaliciousFlow"`
}
CaptchaDay is a nested struct in afs response
type CaptchaIps ¶
type CaptchaIps struct {
CaptchaIp []CaptchaIp `json:"CaptchaIp" xml:"CaptchaIp"`
}
CaptchaIps is a nested struct in afs response
type CaptchaMin ¶
type CaptchaMin struct {
Time string `json:"Time" xml:"Time"`
Pass string `json:"Pass" xml:"Pass"`
Interception string `json:"Interception" xml:"Interception"`
}
CaptchaMin is a nested struct in afs response
type CaptchaMins ¶
type CaptchaMins struct {
CaptchaMin []CaptchaMin `json:"CaptchaMin" xml:"CaptchaMin"`
}
CaptchaMins is a nested struct in afs response
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://help.aliyun.com/document_detail/66217.html
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://help.aliyun.com/document_detail/66223.html
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://help.aliyun.com/document_detail/66222.html
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair attention: rsa key pair auth is only Japan regions available
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://help.aliyun.com/document_detail/66222.html
func (*Client) AnalyzeNvc ¶
func (client *Client) AnalyzeNvc(request *AnalyzeNvcRequest) (response *AnalyzeNvcResponse, err error)
AnalyzeNvc invokes the afs.AnalyzeNvc API synchronously api document: https://help.aliyun.com/api/afs/analyzenvc.html
func (*Client) AnalyzeNvcWithCallback ¶
func (client *Client) AnalyzeNvcWithCallback(request *AnalyzeNvcRequest, callback func(response *AnalyzeNvcResponse, err error)) <-chan int
AnalyzeNvcWithCallback invokes the afs.AnalyzeNvc API asynchronously api document: https://help.aliyun.com/api/afs/analyzenvc.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) AnalyzeNvcWithChan ¶
func (client *Client) AnalyzeNvcWithChan(request *AnalyzeNvcRequest) (<-chan *AnalyzeNvcResponse, <-chan error)
AnalyzeNvcWithChan invokes the afs.AnalyzeNvc API asynchronously api document: https://help.aliyun.com/api/afs/analyzenvc.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) AuthenticateSig ¶
func (client *Client) AuthenticateSig(request *AuthenticateSigRequest) (response *AuthenticateSigResponse, err error)
AuthenticateSig invokes the afs.AuthenticateSig API synchronously api document: https://help.aliyun.com/api/afs/authenticatesig.html
func (*Client) AuthenticateSigWithCallback ¶
func (client *Client) AuthenticateSigWithCallback(request *AuthenticateSigRequest, callback func(response *AuthenticateSigResponse, err error)) <-chan int
AuthenticateSigWithCallback invokes the afs.AuthenticateSig API asynchronously api document: https://help.aliyun.com/api/afs/authenticatesig.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) AuthenticateSigWithChan ¶
func (client *Client) AuthenticateSigWithChan(request *AuthenticateSigRequest) (<-chan *AuthenticateSigResponse, <-chan error)
AuthenticateSigWithChan invokes the afs.AuthenticateSig API asynchronously api document: https://help.aliyun.com/api/afs/authenticatesig.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) ConfigurationStyle ¶
func (client *Client) ConfigurationStyle(request *ConfigurationStyleRequest) (response *ConfigurationStyleResponse, err error)
ConfigurationStyle invokes the afs.ConfigurationStyle API synchronously api document: https://help.aliyun.com/api/afs/configurationstyle.html
func (*Client) ConfigurationStyleWithCallback ¶
func (client *Client) ConfigurationStyleWithCallback(request *ConfigurationStyleRequest, callback func(response *ConfigurationStyleResponse, err error)) <-chan int
ConfigurationStyleWithCallback invokes the afs.ConfigurationStyle API asynchronously api document: https://help.aliyun.com/api/afs/configurationstyle.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) ConfigurationStyleWithChan ¶
func (client *Client) ConfigurationStyleWithChan(request *ConfigurationStyleRequest) (<-chan *ConfigurationStyleResponse, <-chan error)
ConfigurationStyleWithChan invokes the afs.ConfigurationStyle API asynchronously api document: https://help.aliyun.com/api/afs/configurationstyle.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateConfiguration ¶
func (client *Client) CreateConfiguration(request *CreateConfigurationRequest) (response *CreateConfigurationResponse, err error)
CreateConfiguration invokes the afs.CreateConfiguration API synchronously api document: https://help.aliyun.com/api/afs/createconfiguration.html
func (*Client) CreateConfigurationWithCallback ¶
func (client *Client) CreateConfigurationWithCallback(request *CreateConfigurationRequest, callback func(response *CreateConfigurationResponse, err error)) <-chan int
CreateConfigurationWithCallback invokes the afs.CreateConfiguration API asynchronously api document: https://help.aliyun.com/api/afs/createconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateConfigurationWithChan ¶
func (client *Client) CreateConfigurationWithChan(request *CreateConfigurationRequest) (<-chan *CreateConfigurationResponse, <-chan error)
CreateConfigurationWithChan invokes the afs.CreateConfiguration API asynchronously api document: https://help.aliyun.com/api/afs/createconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaDay ¶
func (client *Client) DescribeCaptchaDay(request *DescribeCaptchaDayRequest) (response *DescribeCaptchaDayResponse, err error)
DescribeCaptchaDay invokes the afs.DescribeCaptchaDay API synchronously api document: https://help.aliyun.com/api/afs/describecaptchaday.html
func (*Client) DescribeCaptchaDayWithCallback ¶
func (client *Client) DescribeCaptchaDayWithCallback(request *DescribeCaptchaDayRequest, callback func(response *DescribeCaptchaDayResponse, err error)) <-chan int
DescribeCaptchaDayWithCallback invokes the afs.DescribeCaptchaDay API asynchronously api document: https://help.aliyun.com/api/afs/describecaptchaday.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaDayWithChan ¶
func (client *Client) DescribeCaptchaDayWithChan(request *DescribeCaptchaDayRequest) (<-chan *DescribeCaptchaDayResponse, <-chan error)
DescribeCaptchaDayWithChan invokes the afs.DescribeCaptchaDay API asynchronously api document: https://help.aliyun.com/api/afs/describecaptchaday.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaIpCity ¶
func (client *Client) DescribeCaptchaIpCity(request *DescribeCaptchaIpCityRequest) (response *DescribeCaptchaIpCityResponse, err error)
DescribeCaptchaIpCity invokes the afs.DescribeCaptchaIpCity API synchronously api document: https://help.aliyun.com/api/afs/describecaptchaipcity.html
func (*Client) DescribeCaptchaIpCityWithCallback ¶
func (client *Client) DescribeCaptchaIpCityWithCallback(request *DescribeCaptchaIpCityRequest, callback func(response *DescribeCaptchaIpCityResponse, err error)) <-chan int
DescribeCaptchaIpCityWithCallback invokes the afs.DescribeCaptchaIpCity API asynchronously api document: https://help.aliyun.com/api/afs/describecaptchaipcity.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaIpCityWithChan ¶
func (client *Client) DescribeCaptchaIpCityWithChan(request *DescribeCaptchaIpCityRequest) (<-chan *DescribeCaptchaIpCityResponse, <-chan error)
DescribeCaptchaIpCityWithChan invokes the afs.DescribeCaptchaIpCity API asynchronously api document: https://help.aliyun.com/api/afs/describecaptchaipcity.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaMin ¶
func (client *Client) DescribeCaptchaMin(request *DescribeCaptchaMinRequest) (response *DescribeCaptchaMinResponse, err error)
DescribeCaptchaMin invokes the afs.DescribeCaptchaMin API synchronously api document: https://help.aliyun.com/api/afs/describecaptchamin.html
func (*Client) DescribeCaptchaMinWithCallback ¶
func (client *Client) DescribeCaptchaMinWithCallback(request *DescribeCaptchaMinRequest, callback func(response *DescribeCaptchaMinResponse, err error)) <-chan int
DescribeCaptchaMinWithCallback invokes the afs.DescribeCaptchaMin API asynchronously api document: https://help.aliyun.com/api/afs/describecaptchamin.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaMinWithChan ¶
func (client *Client) DescribeCaptchaMinWithChan(request *DescribeCaptchaMinRequest) (<-chan *DescribeCaptchaMinResponse, <-chan error)
DescribeCaptchaMinWithChan invokes the afs.DescribeCaptchaMin API asynchronously api document: https://help.aliyun.com/api/afs/describecaptchamin.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaOrder ¶
func (client *Client) DescribeCaptchaOrder(request *DescribeCaptchaOrderRequest) (response *DescribeCaptchaOrderResponse, err error)
DescribeCaptchaOrder invokes the afs.DescribeCaptchaOrder API synchronously api document: https://help.aliyun.com/api/afs/describecaptchaorder.html
func (*Client) DescribeCaptchaOrderWithCallback ¶
func (client *Client) DescribeCaptchaOrderWithCallback(request *DescribeCaptchaOrderRequest, callback func(response *DescribeCaptchaOrderResponse, err error)) <-chan int
DescribeCaptchaOrderWithCallback invokes the afs.DescribeCaptchaOrder API asynchronously api document: https://help.aliyun.com/api/afs/describecaptchaorder.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaOrderWithChan ¶
func (client *Client) DescribeCaptchaOrderWithChan(request *DescribeCaptchaOrderRequest) (<-chan *DescribeCaptchaOrderResponse, <-chan error)
DescribeCaptchaOrderWithChan invokes the afs.DescribeCaptchaOrder API asynchronously api document: https://help.aliyun.com/api/afs/describecaptchaorder.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaRisk ¶
func (client *Client) DescribeCaptchaRisk(request *DescribeCaptchaRiskRequest) (response *DescribeCaptchaRiskResponse, err error)
DescribeCaptchaRisk invokes the afs.DescribeCaptchaRisk API synchronously api document: https://help.aliyun.com/api/afs/describecaptcharisk.html
func (*Client) DescribeCaptchaRiskWithCallback ¶
func (client *Client) DescribeCaptchaRiskWithCallback(request *DescribeCaptchaRiskRequest, callback func(response *DescribeCaptchaRiskResponse, err error)) <-chan int
DescribeCaptchaRiskWithCallback invokes the afs.DescribeCaptchaRisk API asynchronously api document: https://help.aliyun.com/api/afs/describecaptcharisk.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeCaptchaRiskWithChan ¶
func (client *Client) DescribeCaptchaRiskWithChan(request *DescribeCaptchaRiskRequest) (<-chan *DescribeCaptchaRiskResponse, <-chan error)
DescribeCaptchaRiskWithChan invokes the afs.DescribeCaptchaRisk API asynchronously api document: https://help.aliyun.com/api/afs/describecaptcharisk.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeConfigName ¶
func (client *Client) DescribeConfigName(request *DescribeConfigNameRequest) (response *DescribeConfigNameResponse, err error)
DescribeConfigName invokes the afs.DescribeConfigName API synchronously api document: https://help.aliyun.com/api/afs/describeconfigname.html
func (*Client) DescribeConfigNameWithCallback ¶
func (client *Client) DescribeConfigNameWithCallback(request *DescribeConfigNameRequest, callback func(response *DescribeConfigNameResponse, err error)) <-chan int
DescribeConfigNameWithCallback invokes the afs.DescribeConfigName API asynchronously api document: https://help.aliyun.com/api/afs/describeconfigname.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeConfigNameWithChan ¶
func (client *Client) DescribeConfigNameWithChan(request *DescribeConfigNameRequest) (<-chan *DescribeConfigNameResponse, <-chan error)
DescribeConfigNameWithChan invokes the afs.DescribeConfigName API asynchronously api document: https://help.aliyun.com/api/afs/describeconfigname.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeEarlyWarning ¶
func (client *Client) DescribeEarlyWarning(request *DescribeEarlyWarningRequest) (response *DescribeEarlyWarningResponse, err error)
DescribeEarlyWarning invokes the afs.DescribeEarlyWarning API synchronously api document: https://help.aliyun.com/api/afs/describeearlywarning.html
func (*Client) DescribeEarlyWarningWithCallback ¶
func (client *Client) DescribeEarlyWarningWithCallback(request *DescribeEarlyWarningRequest, callback func(response *DescribeEarlyWarningResponse, err error)) <-chan int
DescribeEarlyWarningWithCallback invokes the afs.DescribeEarlyWarning API asynchronously api document: https://help.aliyun.com/api/afs/describeearlywarning.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeEarlyWarningWithChan ¶
func (client *Client) DescribeEarlyWarningWithChan(request *DescribeEarlyWarningRequest) (<-chan *DescribeEarlyWarningResponse, <-chan error)
DescribeEarlyWarningWithChan invokes the afs.DescribeEarlyWarning API asynchronously api document: https://help.aliyun.com/api/afs/describeearlywarning.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeOrderInfo ¶
func (client *Client) DescribeOrderInfo(request *DescribeOrderInfoRequest) (response *DescribeOrderInfoResponse, err error)
DescribeOrderInfo invokes the afs.DescribeOrderInfo API synchronously api document: https://help.aliyun.com/api/afs/describeorderinfo.html
func (*Client) DescribeOrderInfoWithCallback ¶
func (client *Client) DescribeOrderInfoWithCallback(request *DescribeOrderInfoRequest, callback func(response *DescribeOrderInfoResponse, err error)) <-chan int
DescribeOrderInfoWithCallback invokes the afs.DescribeOrderInfo API asynchronously api document: https://help.aliyun.com/api/afs/describeorderinfo.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeOrderInfoWithChan ¶
func (client *Client) DescribeOrderInfoWithChan(request *DescribeOrderInfoRequest) (<-chan *DescribeOrderInfoResponse, <-chan error)
DescribeOrderInfoWithChan invokes the afs.DescribeOrderInfo API asynchronously api document: https://help.aliyun.com/api/afs/describeorderinfo.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribePersonMachineList ¶
func (client *Client) DescribePersonMachineList(request *DescribePersonMachineListRequest) (response *DescribePersonMachineListResponse, err error)
DescribePersonMachineList invokes the afs.DescribePersonMachineList API synchronously api document: https://help.aliyun.com/api/afs/describepersonmachinelist.html
func (*Client) DescribePersonMachineListWithCallback ¶
func (client *Client) DescribePersonMachineListWithCallback(request *DescribePersonMachineListRequest, callback func(response *DescribePersonMachineListResponse, err error)) <-chan int
DescribePersonMachineListWithCallback invokes the afs.DescribePersonMachineList API asynchronously api document: https://help.aliyun.com/api/afs/describepersonmachinelist.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribePersonMachineListWithChan ¶
func (client *Client) DescribePersonMachineListWithChan(request *DescribePersonMachineListRequest) (<-chan *DescribePersonMachineListResponse, <-chan error)
DescribePersonMachineListWithChan invokes the afs.DescribePersonMachineList API asynchronously api document: https://help.aliyun.com/api/afs/describepersonmachinelist.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) SetEarlyWarning ¶
func (client *Client) SetEarlyWarning(request *SetEarlyWarningRequest) (response *SetEarlyWarningResponse, err error)
SetEarlyWarning invokes the afs.SetEarlyWarning API synchronously api document: https://help.aliyun.com/api/afs/setearlywarning.html
func (*Client) SetEarlyWarningWithCallback ¶
func (client *Client) SetEarlyWarningWithCallback(request *SetEarlyWarningRequest, callback func(response *SetEarlyWarningResponse, err error)) <-chan int
SetEarlyWarningWithCallback invokes the afs.SetEarlyWarning API asynchronously api document: https://help.aliyun.com/api/afs/setearlywarning.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) SetEarlyWarningWithChan ¶
func (client *Client) SetEarlyWarningWithChan(request *SetEarlyWarningRequest) (<-chan *SetEarlyWarningResponse, <-chan error)
SetEarlyWarningWithChan invokes the afs.SetEarlyWarning API asynchronously api document: https://help.aliyun.com/api/afs/setearlywarning.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateConfigName ¶
func (client *Client) UpdateConfigName(request *UpdateConfigNameRequest) (response *UpdateConfigNameResponse, err error)
UpdateConfigName invokes the afs.UpdateConfigName API synchronously api document: https://help.aliyun.com/api/afs/updateconfigname.html
func (*Client) UpdateConfigNameWithCallback ¶
func (client *Client) UpdateConfigNameWithCallback(request *UpdateConfigNameRequest, callback func(response *UpdateConfigNameResponse, err error)) <-chan int
UpdateConfigNameWithCallback invokes the afs.UpdateConfigName API asynchronously api document: https://help.aliyun.com/api/afs/updateconfigname.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateConfigNameWithChan ¶
func (client *Client) UpdateConfigNameWithChan(request *UpdateConfigNameRequest) (<-chan *UpdateConfigNameResponse, <-chan error)
UpdateConfigNameWithChan invokes the afs.UpdateConfigName API asynchronously api document: https://help.aliyun.com/api/afs/updateconfigname.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
type CodeData ¶
type CodeData struct {
Html string `json:"Html" xml:"Html"`
Net string `json:"Net" xml:"Net"`
Php string `json:"Php" xml:"Php"`
Python string `json:"Python" xml:"Python"`
Java string `json:"Java" xml:"Java"`
NodeJs string `json:"NodeJs" xml:"NodeJs"`
NetUrl string `json:"NetUrl" xml:"NetUrl"`
PhpUrl string `json:"PhpUrl" xml:"PhpUrl"`
PythonUrl string `json:"PythonUrl" xml:"PythonUrl"`
JavaUrl string `json:"JavaUrl" xml:"JavaUrl"`
NodeJsUrl string `json:"NodeJsUrl" xml:"NodeJsUrl"`
}
CodeData is a nested struct in afs response
type ConfigName ¶
type ConfigName struct {
AliUid string `json:"AliUid" xml:"AliUid"`
ConfigName string `json:"ConfigName" xml:"ConfigName"`
RefExtId string `json:"RefExtId" xml:"RefExtId"`
}
ConfigName is a nested struct in afs response
type ConfigNames ¶
type ConfigNames struct {
ConfigName []ConfigName `json:"ConfigName" xml:"ConfigName"`
}
ConfigNames is a nested struct in afs response
type ConfigurationStyleRequest ¶
type ConfigurationStyleRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
ConfigurationMethod string `position:"Query" name:"ConfigurationMethod"`
RefExtId string `position:"Query" name:"RefExtId"`
ApplyType string `position:"Query" name:"ApplyType"`
Scene string `position:"Query" name:"Scene"`
}
ConfigurationStyleRequest is the request struct for api ConfigurationStyle
func CreateConfigurationStyleRequest ¶
func CreateConfigurationStyleRequest() (request *ConfigurationStyleRequest)
CreateConfigurationStyleRequest creates a request to invoke ConfigurationStyle API
type ConfigurationStyleResponse ¶
type ConfigurationStyleResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
CodeData CodeData `json:"CodeData" xml:"CodeData"`
}
ConfigurationStyleResponse is the response struct for api ConfigurationStyle
func CreateConfigurationStyleResponse ¶
func CreateConfigurationStyleResponse() (response *ConfigurationStyleResponse)
CreateConfigurationStyleResponse creates a response to parse from ConfigurationStyle response
type CreateConfigurationRequest ¶
type CreateConfigurationRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
ConfigurationName string `position:"Query" name:"ConfigurationName"`
MaxPV string `position:"Query" name:"MaxPV"`
ConfigurationMethod string `position:"Query" name:"ConfigurationMethod"`
ApplyType string `position:"Query" name:"ApplyType"`
Scene string `position:"Query" name:"Scene"`
}
CreateConfigurationRequest is the request struct for api CreateConfiguration
func CreateCreateConfigurationRequest ¶
func CreateCreateConfigurationRequest() (request *CreateConfigurationRequest)
CreateCreateConfigurationRequest creates a request to invoke CreateConfiguration API
type CreateConfigurationResponse ¶
type CreateConfigurationResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
RefExtId string `json:"RefExtId" xml:"RefExtId"`
}
CreateConfigurationResponse is the response struct for api CreateConfiguration
func CreateCreateConfigurationResponse ¶
func CreateCreateConfigurationResponse() (response *CreateConfigurationResponse)
CreateCreateConfigurationResponse creates a response to parse from CreateConfiguration response
type DescribeCaptchaDayRequest ¶
type DescribeCaptchaDayRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
ConfigName string `position:"Query" name:"ConfigName"`
RefExtId string `position:"Query" name:"RefExtId"`
Time string `position:"Query" name:"Time"`
Type string `position:"Query" name:"Type"`
}
DescribeCaptchaDayRequest is the request struct for api DescribeCaptchaDay
func CreateDescribeCaptchaDayRequest ¶
func CreateDescribeCaptchaDayRequest() (request *DescribeCaptchaDayRequest)
CreateDescribeCaptchaDayRequest creates a request to invoke DescribeCaptchaDay API
type DescribeCaptchaDayResponse ¶
type DescribeCaptchaDayResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
HasData bool `json:"HasData" xml:"HasData"`
CaptchaDay CaptchaDay `json:"CaptchaDay" xml:"CaptchaDay"`
}
DescribeCaptchaDayResponse is the response struct for api DescribeCaptchaDay
func CreateDescribeCaptchaDayResponse ¶
func CreateDescribeCaptchaDayResponse() (response *DescribeCaptchaDayResponse)
CreateDescribeCaptchaDayResponse creates a response to parse from DescribeCaptchaDay response
type DescribeCaptchaIpCityRequest ¶
type DescribeCaptchaIpCityRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
ConfigName string `position:"Query" name:"ConfigName"`
RefExtId string `position:"Query" name:"RefExtId"`
Time string `position:"Query" name:"Time"`
Type string `position:"Query" name:"Type"`
}
DescribeCaptchaIpCityRequest is the request struct for api DescribeCaptchaIpCity
func CreateDescribeCaptchaIpCityRequest ¶
func CreateDescribeCaptchaIpCityRequest() (request *DescribeCaptchaIpCityRequest)
CreateDescribeCaptchaIpCityRequest creates a request to invoke DescribeCaptchaIpCity API
type DescribeCaptchaIpCityResponse ¶
type DescribeCaptchaIpCityResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
HasData bool `json:"HasData" xml:"HasData"`
CaptchaCities []CaptchaCitie `json:"CaptchaCities" xml:"CaptchaCities"`
CaptchaIps []CaptchaIp `json:"CaptchaIps" xml:"CaptchaIps"`
}
DescribeCaptchaIpCityResponse is the response struct for api DescribeCaptchaIpCity
func CreateDescribeCaptchaIpCityResponse ¶
func CreateDescribeCaptchaIpCityResponse() (response *DescribeCaptchaIpCityResponse)
CreateDescribeCaptchaIpCityResponse creates a response to parse from DescribeCaptchaIpCity response
type DescribeCaptchaMinRequest ¶
type DescribeCaptchaMinRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
ConfigName string `position:"Query" name:"ConfigName"`
RefExtId string `position:"Query" name:"RefExtId"`
Time string `position:"Query" name:"Time"`
Type string `position:"Query" name:"Type"`
}
DescribeCaptchaMinRequest is the request struct for api DescribeCaptchaMin
func CreateDescribeCaptchaMinRequest ¶
func CreateDescribeCaptchaMinRequest() (request *DescribeCaptchaMinRequest)
CreateDescribeCaptchaMinRequest creates a request to invoke DescribeCaptchaMin API
type DescribeCaptchaMinResponse ¶
type DescribeCaptchaMinResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
HasData bool `json:"HasData" xml:"HasData"`
CaptchaMins []CaptchaMin `json:"CaptchaMins" xml:"CaptchaMins"`
}
DescribeCaptchaMinResponse is the response struct for api DescribeCaptchaMin
func CreateDescribeCaptchaMinResponse ¶
func CreateDescribeCaptchaMinResponse() (response *DescribeCaptchaMinResponse)
CreateDescribeCaptchaMinResponse creates a response to parse from DescribeCaptchaMin response
type DescribeCaptchaOrderRequest ¶
type DescribeCaptchaOrderRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
Lang string `position:"Query" name:"Lang"`
}
DescribeCaptchaOrderRequest is the request struct for api DescribeCaptchaOrder
func CreateDescribeCaptchaOrderRequest ¶
func CreateDescribeCaptchaOrderRequest() (request *DescribeCaptchaOrderRequest)
CreateDescribeCaptchaOrderRequest creates a request to invoke DescribeCaptchaOrder API
type DescribeCaptchaOrderResponse ¶
type DescribeCaptchaOrderResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
}
DescribeCaptchaOrderResponse is the response struct for api DescribeCaptchaOrder
func CreateDescribeCaptchaOrderResponse ¶
func CreateDescribeCaptchaOrderResponse() (response *DescribeCaptchaOrderResponse)
CreateDescribeCaptchaOrderResponse creates a response to parse from DescribeCaptchaOrder response
type DescribeCaptchaRiskRequest ¶
type DescribeCaptchaRiskRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
ConfigName string `position:"Query" name:"ConfigName"`
RefExtId string `position:"Query" name:"RefExtId"`
Time string `position:"Query" name:"Time"`
}
DescribeCaptchaRiskRequest is the request struct for api DescribeCaptchaRisk
func CreateDescribeCaptchaRiskRequest ¶
func CreateDescribeCaptchaRiskRequest() (request *DescribeCaptchaRiskRequest)
CreateDescribeCaptchaRiskRequest creates a request to invoke DescribeCaptchaRisk API
type DescribeCaptchaRiskResponse ¶
type DescribeCaptchaRiskResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
NumOfThisMonth int `json:"NumOfThisMonth" xml:"NumOfThisMonth"`
NumOfLastMonth int `json:"NumOfLastMonth" xml:"NumOfLastMonth"`
RiskLevel string `json:"RiskLevel" xml:"RiskLevel"`
}
DescribeCaptchaRiskResponse is the response struct for api DescribeCaptchaRisk
func CreateDescribeCaptchaRiskResponse ¶
func CreateDescribeCaptchaRiskResponse() (response *DescribeCaptchaRiskResponse)
CreateDescribeCaptchaRiskResponse creates a response to parse from DescribeCaptchaRisk response
type DescribeConfigNameRequest ¶
type DescribeConfigNameRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
}
DescribeConfigNameRequest is the request struct for api DescribeConfigName
func CreateDescribeConfigNameRequest ¶
func CreateDescribeConfigNameRequest() (request *DescribeConfigNameRequest)
CreateDescribeConfigNameRequest creates a request to invoke DescribeConfigName API
type DescribeConfigNameResponse ¶
type DescribeConfigNameResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
HasConfig bool `json:"HasConfig" xml:"HasConfig"`
BizCode string `json:"BizCode" xml:"BizCode"`
ConfigNames []ConfigName `json:"ConfigNames" xml:"ConfigNames"`
}
DescribeConfigNameResponse is the response struct for api DescribeConfigName
func CreateDescribeConfigNameResponse ¶
func CreateDescribeConfigNameResponse() (response *DescribeConfigNameResponse)
CreateDescribeConfigNameResponse creates a response to parse from DescribeConfigName response
type DescribeEarlyWarningRequest ¶
type DescribeEarlyWarningRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
}
DescribeEarlyWarningRequest is the request struct for api DescribeEarlyWarning
func CreateDescribeEarlyWarningRequest ¶
func CreateDescribeEarlyWarningRequest() (request *DescribeEarlyWarningRequest)
CreateDescribeEarlyWarningRequest creates a request to invoke DescribeEarlyWarning API
type DescribeEarlyWarningResponse ¶
type DescribeEarlyWarningResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
HasWarning bool `json:"HasWarning" xml:"HasWarning"`
BizCode string `json:"BizCode" xml:"BizCode"`
EarlyWarnings []EarlyWarning `json:"EarlyWarnings" xml:"EarlyWarnings"`
}
DescribeEarlyWarningResponse is the response struct for api DescribeEarlyWarning
func CreateDescribeEarlyWarningResponse ¶
func CreateDescribeEarlyWarningResponse() (response *DescribeEarlyWarningResponse)
CreateDescribeEarlyWarningResponse creates a response to parse from DescribeEarlyWarning response
type DescribeOrderInfoRequest ¶
type DescribeOrderInfoRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
}
DescribeOrderInfoRequest is the request struct for api DescribeOrderInfo
func CreateDescribeOrderInfoRequest ¶
func CreateDescribeOrderInfoRequest() (request *DescribeOrderInfoRequest)
CreateDescribeOrderInfoRequest creates a request to invoke DescribeOrderInfo API
type DescribeOrderInfoResponse ¶
type DescribeOrderInfoResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
OrderLevel string `json:"OrderLevel" xml:"OrderLevel"`
Num string `json:"Num" xml:"Num"`
BeginDate string `json:"BeginDate" xml:"BeginDate"`
EndDate string `json:"EndDate" xml:"EndDate"`
}
DescribeOrderInfoResponse is the response struct for api DescribeOrderInfo
func CreateDescribeOrderInfoResponse ¶
func CreateDescribeOrderInfoResponse() (response *DescribeOrderInfoResponse)
CreateDescribeOrderInfoResponse creates a response to parse from DescribeOrderInfo response
type DescribePersonMachineListRequest ¶
type DescribePersonMachineListRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
}
DescribePersonMachineListRequest is the request struct for api DescribePersonMachineList
func CreateDescribePersonMachineListRequest ¶
func CreateDescribePersonMachineListRequest() (request *DescribePersonMachineListRequest)
CreateDescribePersonMachineListRequest creates a request to invoke DescribePersonMachineList API
type DescribePersonMachineListResponse ¶
type DescribePersonMachineListResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
PersonMachineRes PersonMachineRes `json:"PersonMachineRes" xml:"PersonMachineRes"`
}
DescribePersonMachineListResponse is the response struct for api DescribePersonMachineList
func CreateDescribePersonMachineListResponse ¶
func CreateDescribePersonMachineListResponse() (response *DescribePersonMachineListResponse)
CreateDescribePersonMachineListResponse creates a response to parse from DescribePersonMachineList response
type EarlyWarning ¶
type EarlyWarning struct {
WarnOpen bool `json:"WarnOpen" xml:"WarnOpen"`
Title string `json:"Title" xml:"Title"`
Content string `json:"Content" xml:"Content"`
Frequency string `json:"Frequency" xml:"Frequency"`
TimeOpen bool `json:"TimeOpen" xml:"TimeOpen"`
TimeBegin string `json:"TimeBegin" xml:"TimeBegin"`
TimeEnd string `json:"TimeEnd" xml:"TimeEnd"`
Channel string `json:"Channel" xml:"Channel"`
}
EarlyWarning is a nested struct in afs response
type EarlyWarnings ¶
type EarlyWarnings struct {
EarlyWarning []EarlyWarning `json:"EarlyWarning" xml:"EarlyWarning"`
}
EarlyWarnings is a nested struct in afs response
type PersonMachine ¶
type PersonMachine struct {
ConfigurationName string `json:"ConfigurationName" xml:"ConfigurationName"`
Appkey string `json:"Appkey" xml:"Appkey"`
ConfigurationMethod string `json:"ConfigurationMethod" xml:"ConfigurationMethod"`
ApplyType string `json:"ApplyType" xml:"ApplyType"`
Scene string `json:"Scene" xml:"Scene"`
LastUpdate string `json:"LastUpdate" xml:"LastUpdate"`
ExtId string `json:"ExtId" xml:"ExtId"`
SceneOriginal string `json:"SceneOriginal" xml:"SceneOriginal"`
}
PersonMachine is a nested struct in afs response
type PersonMachineRes ¶
type PersonMachineRes struct {
HasConfiguration string `json:"HasConfiguration" xml:"HasConfiguration"`
PersonMachines []PersonMachine `json:"PersonMachines" xml:"PersonMachines"`
}
PersonMachineRes is a nested struct in afs response
type PersonMachines ¶
type PersonMachines struct {
PersonMachine []PersonMachine `json:"PersonMachine" xml:"PersonMachine"`
}
PersonMachines is a nested struct in afs response
type SetEarlyWarningRequest ¶
type SetEarlyWarningRequest struct {
*requests.RpcRequest
TimeEnd string `position:"Query" name:"TimeEnd"`
WarnOpen requests.Boolean `position:"Query" name:"WarnOpen"`
SourceIp string `position:"Query" name:"SourceIp"`
Channel string `position:"Query" name:"Channel"`
Title string `position:"Query" name:"Title"`
TimeOpen requests.Boolean `position:"Query" name:"TimeOpen"`
TimeBegin string `position:"Query" name:"TimeBegin"`
Frequency string `position:"Query" name:"Frequency"`
}
SetEarlyWarningRequest is the request struct for api SetEarlyWarning
func CreateSetEarlyWarningRequest ¶
func CreateSetEarlyWarningRequest() (request *SetEarlyWarningRequest)
CreateSetEarlyWarningRequest creates a request to invoke SetEarlyWarning API
type SetEarlyWarningResponse ¶
type SetEarlyWarningResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
}
SetEarlyWarningResponse is the response struct for api SetEarlyWarning
func CreateSetEarlyWarningResponse ¶
func CreateSetEarlyWarningResponse() (response *SetEarlyWarningResponse)
CreateSetEarlyWarningResponse creates a response to parse from SetEarlyWarning response
type UpdateConfigNameRequest ¶
type UpdateConfigNameRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
ConfigName string `position:"Query" name:"ConfigName"`
RefExtId string `position:"Query" name:"RefExtId"`
Lang string `position:"Query" name:"Lang"`
}
UpdateConfigNameRequest is the request struct for api UpdateConfigName
func CreateUpdateConfigNameRequest ¶
func CreateUpdateConfigNameRequest() (request *UpdateConfigNameRequest)
CreateUpdateConfigNameRequest creates a request to invoke UpdateConfigName API
type UpdateConfigNameResponse ¶
type UpdateConfigNameResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
BizCode string `json:"BizCode" xml:"BizCode"`
}
UpdateConfigNameResponse is the response struct for api UpdateConfigName
func CreateUpdateConfigNameResponse ¶
func CreateUpdateConfigNameResponse() (response *UpdateConfigNameResponse)
CreateUpdateConfigNameResponse creates a response to parse from UpdateConfigName response
Source Files
¶
- analyze_nvc.go
- authenticate_sig.go
- client.go
- configuration_style.go
- create_configuration.go
- describe_captcha_day.go
- describe_captcha_ip_city.go
- describe_captcha_min.go
- describe_captcha_order.go
- describe_captcha_risk.go
- describe_config_name.go
- describe_early_warning.go
- describe_order_info.go
- describe_person_machine_list.go
- set_early_warning.go
- struct_captcha_citie.go
- struct_captcha_cities.go
- struct_captcha_day.go
- struct_captcha_ip.go
- struct_captcha_ips.go
- struct_captcha_min.go
- struct_captcha_mins.go
- struct_code_data.go
- struct_config_name.go
- struct_config_names.go
- struct_early_warning.go
- struct_early_warnings.go
- struct_person_machine.go
- struct_person_machine_res.go
- struct_person_machines.go
- update_config_name.go